@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 # shortcuts
 #  os and distros
@@ -488,6 +488,14 @@ sub mapping {
        # Neither libgcrypt11 nor libgcrypt20 seem to work.
        [package => 'libgcrypt11-dev']]],
 
+     [cpanmod => 'Crypt::HC128',
+      [os_freebsd,
+       [package => 'wolfssl']],
+      [like_debian,
+       [linuxdistrocodename => 'xenial',
+	[package => 'libwolfssl-dev']]],
+     ],
+
      [cpanmod => ['Crypt::MCrypt', 'Mcrypt'],
       [os_freebsd,
        [package => 'libmcrypt']],
@@ -1330,6 +1338,13 @@ sub mapping {
       [like_debian,
        [package => 'liblua5.1-0-dev']]],
 
+     [cpanmod => 'Inline::Perl6',
+      [like_debian,
+       # XXX tests fail on Ubuntu16.04; <dynload.h> missing on stretch
+       [linuxdistrocodename => [qw(stretch xenial)],
+	[package => [qw(moarvm-dev libuv1-dev libatomic-ops-dev libtommath-dev rakudo)]]]],
+     ],
+
      [cpanmod => 'Inline::Python',
       [os_freebsd,
        [package => 'python']],
@@ -1565,6 +1580,8 @@ sub mapping {
        [package => 'libmpc-dev']],
       [like_fedora,
        [package => 'libmpc-devel']],
+      [os_darwin,
+       [package => 'libmpc']],
      ],
 
      [cpanmod => 'Math::MPFI',
@@ -1670,6 +1687,17 @@ sub mapping {
        [package => 'libesmtp-devel']],
      ],
 
+     [cpanmod => 'Net::Ifstat',
+      [os_freebsd,
+       [package => 'ifstat']],
+      [like_debian,
+       [package => 'ifstat']],
+      [like_fedora,
+       [package => 'iproute']],
+      [os_darwin,
+       [package => 'ifstat']],
+     ],
+
      [cpanmod => 'Net::Jabber::Loudmouth',
       [os_freebsd,
        [package => 'loudmouth']],
@@ -1827,6 +1855,13 @@ sub mapping {
        [package => ['libogg-devel', 'libvorbis-devel']]],
      ],
 
+     [cpanmod => 'Ogre',
+      [os_freebsd,
+       [package => 'ogre3d']], # untested
+      [like_debian,
+       [package => 'libogre-1.9-dev']], # compilation failures
+     ],
+
      [cpanmod => 'OIS',
       ## ois in freebsd ports is 1.2.0, but 1.3.0 is required
       #[os_freebsd,
